@@ -92,7 +92,7 @@ def getTranslatedMessage(mode,message , key):
 @click.group(
     cls=HelpColorsGroup, help_headers_color="yellow", help_options_color="cyan"
 )
-@click.version_option('0.1.3')
+@click.version_option('0.1.4')
 def main():
     """PassRack: Encrypt, decrypt and save your passwords"""
     pass
@@ -114,8 +114,8 @@ def encrypt(content, note):
     msg = cryptocode.encrypt(cce, cek)
     file = open((os.path.join(os.path.expanduser("~"), ".passrack", ".data_encr.dat")), 'a')
     file.write((msg+f'------------------ {note}'+'\n'))
-
-    
+    click.clear()
+    click.secho('Encryption Successful')
 
 '''
 ================================================================================================
@@ -158,31 +158,29 @@ def decrypt(note):
 
 '''
 ================================================================================================
-================================================================================================
+===========================================4=====================================================
 '''
 
 # Mass DECRYPTION LOGIC
 
 @main.command('decryptf', help='Decrypt all your passwords')
 def decrypt():
+    
     cck = pickle.load(open((os.path.join(os.path.expanduser("~"), ".passrack", ".cck.dat")), 'rb'))
     cek = pickle.load(open((os.path.join(os.path.expanduser("~"), ".passrack", ".key.dat")), 'rb'))
     inp = click.prompt(click.style('Enter your password', fg='cyan', bg = "black"),hide_input=True ,confirmation_prompt=True)
     ops = pickle.load(open((os.path.join(os.path.expanduser("~"), ".passrack", ".passrack.dat")), 'rb'))
     ops = cryptocode.decrypt(ops, cek)
     if inp==ops:
+        click.clear()
         a = open((os.path.join(os.path.expanduser("~"), ".passrack", ".data_encr.dat")), 'r')
         b = a.readlines()
-        cd=[]
         for line in b:
-            cd.append(line)
-        for c in cd:   
-
             c = line
             
             dmsg = cryptocode.decrypt(c, cek)
             ccd = getTranslatedMessage('d', dmsg, cck) 
-            click.clear()
+            
             secho(ccd, fg='cyan', bg = "black")
     else:
         secho('Invalid Password', fg='red', bg= 'black')
